!2345678901234567890223456789032345678904234567890523456789062345678907234567890
! ******************************************************************************
! **  set physical parameters                         **
! ******************************************************************************
   subroutine add_physp

      use mod_cswitch
      use mod_physp
      use mod_thermp

      implicit none
!      real(8):: Tp45_D
      real(8):: Qint45
!      real(8):: DT_Man,  HF45_sur, HFC_sur
      real(8):: T_Eta
      real(8):: Nu_sur,  Ra_ref
      real(8):: r_ICB,   T_CMB

!   Open log file

      open ( 20, file = 'add_phys_para.data' )    
      write ( 20,* ) '# **** Additional physcal parameters ****'  

!   pi

      pi     = 4.0d0 * atan( 1.0d0 )

      write ( 20,* ) '# Pi   '
      write ( 20,* ) pi

!   Seconds of 1 Billions of year

      SecBy  = 24.0d0 * 3600.0d0 * 365.256363d0 * 1.0d9 

      write ( 20,* ) '# (1)  Seconds of 1 Billions of year'
      write ( 20,* ) SecBy

!    Seconds of the planet age

      ts_45  = tBa_45 * SecBy

      write ( 20,* ) '# (2)  Seconds of the planet age'
      write ( 20,* ) ts_45

!   Volume and density of the mantle and core

      V_Man  = 4.0d0 / 3.0d0 * pi * ( R_0**3 - R_CMB**3 )
      V_Core = 4.0d0 / 3.0d0 * pi * R_CMB**3

      rho_Man   = M_Man  / V_Man
      rho_Core  = M_core / V_Core

      write ( 20,* ) '# (4)  Volume of the mantle'
      write ( 20,* ) V_Man
      write ( 20,* ) '# (5)  Volume of the core'
      write ( 20,* ) V_Core
      write ( 20,* ) '# (6)  Mean density of the mantle'
      write ( 20,* ) rho_Man
      write ( 20,* ) '# (7)  Mean density of the core'
      write ( 20,* ) rho_Core

!   Convesion factor between potential and mean temperatures

      call Tmp_fact_M
      call Tmp_fact_C

      write ( 20,* ) '# (8) Factor to convert average T to potential T of mantle'
      write ( 20,* ) Theta_M
      write ( 20,* ) '# (9) Factor to convert average T to potential T of core'
      write ( 20,* ) Theta_C

!   Surface areas of the planetary sruface and CMB

      S_Man = 4.0d0 * pi * R_0  **2 
      S_CMB = 4.0d0 * pi * R_CMB**2 

      write ( 20,* ) '# (10)  Surface area of the planetary surface'
      write ( 20,* ) S_Man
      write ( 20,* ) '# (11)  Surface area of the core-mantle boundary'
      write ( 20,* ) S_CMB

!   Heat capacity

      C_Man  = M_Man  * Cp_M
      C_Core = M_Core * Cp_C 
!      C_Man  = C_Man + C_Core

      write ( 20,* ) '# (12) Heat capacity of the mantle'
      write ( 20,* ) C_Man
      write ( 20,* ) '# (13) Heat capacity of the core'
      write ( 20,* ) C_Core

!   Thickness of mantle

      D_Man  = R_0 - R_CMB

      write ( 20,* ) '# (14) Thickness of the mantle'
      write ( 20,* ) D_Man

!   Thermal conductivity

      k_M    = rho_Man * Cp_M * kap_M

      write ( 20,* ) '# (15) Thermal conductibvity of the mantle'
      write ( 20,* ) k_M

!   Decay constant

      L_238  = dlog( 2.0d0 ) / ( t_238 * SecBy ) 
      L_235  = dlog( 2.0d0 ) / ( t_235 * SecBy ) 
      L_Th   = dlog( 2.0d0 ) / ( t_Th  * SecBy ) 
      L_K40  = dlog( 2.0d0 ) / ( t_K40 * SecBy ) 

      write ( 20,* ) '# (16) Decay constant of 238U'
      write ( 20,* ) L_238
      write ( 20,* ) '# (17) Decay constant of 235U'
      write ( 20,* ) L_235
      write ( 20,* ) '# (18) Decay constant of Th'
      write ( 20,* ) L_Th
      write ( 20,* ) '# (19) Decay constant of 40K'
      write ( 20,* ) L_K40

!   Total internal heating per mass and correction of total U concentration

      if ( ICAL == 1 ) then
        Qint45 = C_U * (  R_238 * H_238 + R_235 * H_235                 &
                        + R_Th  * H_Th  + R_K40 * H_K40 )
       else
        Qint45 = Q45_sur * Urey45 / M_Man
        C_U    = Qint45 / (  R_238 * H_238 + R_235 * H_235              &
                           + R_Th  * H_Th  + R_K40 * H_K40 )
      end if

      write ( 20,* ) '# (20) Total internal heating (ICAL=1)'
      write ( 20,* ) Qint45
      write ( 20,* ) '# (21) Corrected value of U concentration to adjust Urey ratio'
      write ( 20,* ) C_U


!   Average temperature for reference visocity

      T_Eta  = ThInv_M * Tp45_M

      write ( 20,* ) '# (22) Average temperature for reference visocity'
      write ( 20,* ) T_Eta

!   Pre-exponential factor of viscosity

      A_Eta    = Eta45 * exp ( -Hstar / ( R_gas * T_Eta ) )

      write ( 20,* ) '# (23) Pre-exponential factor of viscosity'
      write ( 20,* ) A_Eta

!   Coefficient of Nu for Ra^beta

!      call set_Ra_Nu( HF45_sur, Tp45_D, DT_Man, Ra_ref, Nu_sur )
      call set_Ra_Nu( Ra_ref, Nu_sur )

!      write ( 20,* ) '# (24) Reference or terminal D" temperature'
!      write ( 20,* ) Tp45_D
!      write ( 20,* ) '# (25) Reference temperature difference through the mantle'
!      write ( 20,* ) DT_Man
!      write ( 20,* ) '# (26) Reference or terminal heat flux of the surface'
!      write ( 20,* ) HF45_sur
!      write ( 20,* ) '# (27) Reference or terminal conductive heat flux of the surface'
!      write ( 20,* ) HFC_sur
      write ( 20,* ) '# (28) Reference or terminal Nusselt number of the surface'
      write ( 20,* ) Nu_sur
      write ( 20,* ) '# (29) Reference or terminal Rayleigh number of the mantle'
      write ( 20,* ) Ra_ref
      write ( 20,* ) '# (30) Coefficient in the Nu-Ra relation for upper surface'
      write ( 20,* ) A_RaNu_U
      write ( 20,* ) '# (31) Coefficient in the Nu-Ra relation for lower surface'
      write ( 20,* ) A_RaNu_L

!  Seismic parameter of the core

      phi_C = Vp_C**2

      write ( 20,* ) '# (32) Seismic parameter of the core'
      write ( 20,* ) phi_C

!   Melting temperature of the core at CMB

      If ( ICAL  == 1 ) then
        Tm_CMB = TmF_CMB
       else
        r_ICB = r45_ICB
        T_CMB = T45_CMB 
        call set_Tmlt_C( r_ICB, T_CMB )
        Tm_CMB = TmT_CMB
      End if

      write ( 20,* ) '# (33) Core melting temperature at CMB to adjust IC radius'
      write ( 20,* ) Tm_CMB

!   Set time step interval

      if ( ICAL == 1 ) then
        dtBy = tBa_45 / dfloat( Nt )
       else
        dtBy = -tBa_45 / dfloat( Nt )
      end if

      dt = dtBy * SecBy

      write ( 20,* ) '# (34) Time step interval [By]'
      write ( 20,* ) dtBy
      write ( 20,* ) '# (35) Time step interval [sec]'
      write ( 20,* ) dt

      return

   end subroutine add_physp

