!2345678901234567890223456789032345678904234567890523456789062345678907234567890
! ******************************************************************************
! *   Solve ICB position by a Newton method                          **
! ****************************************************************************** 

   subroutine cal_ICB_radi( r_ICB, T_CMB )

      use mod_physp
      use mod_thermp

      implicit none
      real(8):: r_ICB, T_CMB

      real(8):: T_cen, Tm_cen
      real(8):: Fx, dFdx, x,   xnew, res
      integer:: it, Nitr, ICB

      real(8):: A, B, C, D, E, F

!   Set additional parameters

!      write ( 6,* ) 'Tm_CMB =',Tm_CMB
!      write ( 6,* ) 'R_CMB phi_C=',R_CMB,phi_c

      A = 0.5d0 * alph_C * g_0 / ( Cp_C * R_CMB )
      B = T_CMB * exp( A * R_CMB**2 )
      C = Tm_CMB * ( 1.0d0 - gTm_C / P_CMB * phi_C * rho_CMB )
      D = 0.5d0 * g_0 / ( phi_C * R_CMB )
      E = rho_CMB * exp( D * R_CMB**2 )
      F = Tm_CMB * gTm_C / P_CMB * phi_C * E

!      write ( 6,* ) 'A, B, C, D, E, F'
!      write ( 6,* ) A, B, C, D, E, F

!   Temperature at the planetary center 

      T_cen  = B
      Tm_cen = C + F 

!   Check of the closs point
 
      if ( T_CMB < Tm_CMB ) then        !  Solid core
        ICB = 2
       else if ( T_cen < Tm_cen ) then  !  liquid and solid core
        ICB = 1
       else                             !  liquid core
        ICB = 0
      end if

      if ( ICB == 0 ) then

        r_ICB = 0.0d0

!        write ( 6,* ) ICB,'Liquid core',r_ICB 

       else if ( ICB == 1 ) then

        Nitr = 100
        x = R_CMB

        do it = 1, Nitr
          Fx   = C + F * exp( -D * x**2 ) - B * exp( -A * x**2 )
          dFdx = -2.0d0 * D * F * x * exp( -D * x**2 )                  & 
                + 2.0d0 * B * A * x * exp( -A * x**2 )
!          write ( 6,* ) it, x, Fx, dFdx 
          xnew = x - Fx / dFdx
          res = dabs( ( xnew - x ) / x )
          x = xnew
!          write ( 6,* ) it, res
          if ( res < 1.0d-6 ) exit
        end do

        r_ICB = x

!        write ( 6,* ) ICB,'ICB radius =',r_ICB 

       else

        r_ICB = R_CMB

!        write ( 6,* ) ICB,'Solid core',r_ICB  

      end if

      return

   end subroutine cal_ICB_radi

