!2345678901234567890223456789032345678904234567890523456789062345678907234567890
! ******************************************************************************
! **  calculate heat flow                        **
! ******************************************************************************
   subroutine cal_heatf( Q_sur,  Q_CMB,  HF_sur, HF_CMB,                           &
                         DT_sur, DT_CMB, Ra_Man, Ra_U,   Ra_L,   Ra_sur, Ra_CMB )

      use mod_cswitch
      use mod_physp

      implicit none
      real(8):: Q_sur,  Q_CMB
      real(8):: DT_sur, DT_CMB  
      real(8):: Ra_Man, Ra_U,   Ra_L,   Ra_sur, Ra_CMB

      real(8):: Nu_sur, Nu_CMB
      real(8):: HFC_sur,HFC_CMB
      real(8):: HF_sur, HF_CMB

!  Conductive heat flux

      if ( IPRN == 1 ) then

        HFC_sur = k_M * ( DT_sur + DT_CMB ) * R_CMB / ( D_Man * R_0 )
        HFC_CMB = k_M * ( DT_sur + DT_CMB ) * R_0   / ( D_Man * R_CMB )
        Nu_sur  = A_RaNu_U * Ra_Man ** beta_U
        Nu_CMB  = Nu_sur

       else if ( IPRN == 2 ) then

        HFC_sur = k_M * DT_sur * R_CMB / ( D_Man * R_0 )
        HFC_CMB = k_M * DT_CMB * R_0   / ( D_Man * R_CMB )
        Nu_sur  = A_RaNu_U * Ra_U   ** beta_U
        Nu_CMB  = A_RaNu_L * Ra_L   ** beta_L

       else if ( IPRN == 3 ) then

        HFC_sur = k_M * DT_sur * R_CMB / ( D_Man * R_0 )
        HFC_CMB = k_M * DT_CMB * R_0   / ( D_Man * R_CMB )
        Nu_sur  = A_RaNu_U * Ra_sur ** beta_U
        Nu_CMB  = A_RaNu_L * Ra_CMB ** beta_L

       else if ( IPRN == 5 ) then

        HFC_sur = k_M * DT_sur * R_CMB / ( D_Man * R_0 )
        HFC_CMB = k_M * DT_CMB * R_0   / ( D_Man * R_CMB )
        Nu_sur  = A_RaNu_U * Ra_sur ** beta_U
        Nu_CMB  = Nu_sur

       else if ( IPRN == 11 ) then

        HFC_sur = k_M * DT_sur / D_Man
        HFC_CMB = k_M * DT_CMB / D_Man
        Nu_sur  = A_RaNu_U * Ra_Man ** beta_U
        Nu_CMB  = Nu_sur

       else if ( IPRN == 12 ) then

        HFC_sur = k_M * DT_sur / D_Man
        HFC_CMB = k_M * DT_CMB / D_Man
        Nu_sur  = A_RaNu_U * Ra_U   ** beta_U
        Nu_CMB  = A_RaNu_L * Ra_L   ** beta_L

       else if ( IPRN == 13 .or. IPRN == 14 ) then

        HFC_sur = k_M * DT_sur / D_Man
        HFC_CMB = k_M * DT_CMB / D_Man
        Nu_sur  = A_RaNu_U * Ra_sur ** beta_U
        Nu_CMB  = A_RaNu_L * Ra_CMB ** beta_L

       else if ( IPRN == 21 ) then

        HFC_sur = k_M * DT_sur / D_Man
        HFC_CMB = k_M * DT_CMB / D_Man
        Nu_sur  = A_RaNu_U * Ra_Man ** beta_U
        Nu_CMB  = Nu_sur                      * dsqrt( R_0 / R_CMB )

       else if ( IPRN == 22 ) then

        HFC_sur = k_M * DT_sur / D_Man
        HFC_CMB = k_M * DT_CMB / D_Man
        Nu_sur  = A_RaNu_U * Ra_U   ** beta_U
        Nu_CMB  = A_RaNu_L * Ra_L   ** beta_L * dsqrt( R_0 / R_CMB )

       else if ( IPRN == 23 ) then

        HFC_sur = k_M * DT_sur / D_Man
        HFC_CMB = k_M * DT_CMB / D_Man
        Nu_sur  = A_RaNu_U * Ra_sur ** beta_U
        Nu_CMB  = A_RaNu_L * Ra_CMB ** beta_L * dsqrt( R_0 / R_CMB )

      end if

!  Surface heat flow
 
      HF_sur  = Nu_sur * HFC_sur      
      Q_sur   = S_Man  * HF_sur      

!  Surface heat flow

      HF_CMB  = Nu_CMB * HFC_CMB      
      Q_CMB   = S_CMB  * HF_CMB  

!      write ( 6,* ) 'Rayleigh number =', Ra_sur, Ra_CMB
!      write ( 6,* ) 'Conductive heat flux =', HFC_sur, HFC_CMB
!      write ( 6,* ) 'Nusselt numbers =', Nu_sur, Nu_CMB    
!      write ( 6,* ) 'Convective heat flux =', HF_sur, HF_CMB

      return

   end subroutine cal_heatf
