!2345678901234567890223456789032345678904234567890523456789062345678907234567890
! ******************************************************************************
! **  Calculate thermal history of the terrestrial planets                    **
! **  using parameterized convection theory                                   **
! ******************************************************************************

   program th_main

!   Load modules
  
      use mod_cswitch
      use mod_physp
      use mod_thermp

!   Type difinition

      implicit none
      real(8):: T_Man,   Tp_M,    Tp_D,    T_CMB  
      real(8):: T_Core,  T_ICB,   r_ICB
      real(8):: T_Man_N, T_Core_N
      real(8):: t,       tBy

      real(8):: t0,      t1,      t2
      real(8):: F_Man1,  F_Man2,  F_Man3,  F_Man4
      real(8):: F_Core1, F_Core2, F_Core3, F_Core4
      real(8):: T_Man0,  T_Man1,  T_Man2,  T_Man3
      real(8):: T_Core0, T_Core1, T_Core2, T_Core3
      real(8):: Tp_M0,   Tp_M1,   Tp_M2,   Tp_M3
      real(8):: T_CMB0,  T_CMB1,  T_CMB2,  T_CMB3
      real(8):: Q_Man0,  Q_Man1,  Q_Man2,  Q_Man3
      real(8):: Q_CMB0,  Q_CMB1,  Q_CMB2,  Q_CMB3

      real(8):: T_Man_C, Tp_M_C,  Tp_D_C,  T_CMB_C  
      real(8):: T_Core_C,T_ICB_C, r_ICB_K

      integer:: it,      iRKS

!   Set model control switches

      call set_cswitch

!   Set thermal conditions

      call set_therm_cond

!   Set physcal parameters

      call set_physp

! Forward calculation from 45 Ba

      If ( ICAL == 1 ) then

        Tp_M  = Tp00_M
        T_CMB = T00_CMB
        r_ICB = 0.0d0

! Backward calculation from 0 Ba
            
       else          
        Tp_M  = Tp45_M
        T_CMB = T45_CMB
        r_ICB = r45_ICB

!  Core melting temperature adjusted to inner core radius

!        call set_Tmlt_C( r_ICB, T_CMB )   

      end if

!   calculate D" temperature

      call cal_Tp_D( Tp_D, Tp_M )

!   Convesion factor between potential and mean temperatures

!      call Tmp_fact_M
!      call Tmp_fact_C

!   Calculate additional physical parameters

      call add_physp

!   Calculate Inital mean temperature

      T_Man  = ThInv_M * Tp_M
      T_Core = ThInv_C * T_CMB

!   Calculate ICB temperature

      call cal_ICB_Tmp( T_ICB, T_CMB, r_ICB )

!   Set initial or terminal time 

      if ( ICAL == 1 ) then
        tBy  = 0.0d0
        t    = 0.0d0
       else
        tBy  = tBa_45
        t    = tBa_45 * SecBy
      end if

!      write ( 6,* ) 'Initial age or time=',tBy,t

!      stop

!   Open file for output

      open ( 21, file='Tmp_evo.data' )
      open ( 22, file='Heat_evo.data' )
      open ( 23, file='RaNu_evo.data' )


!   Start calculation -----------------------------------------------------------

      it   = 0

!   Output inital condition to file

!        Write ( 6,* )  it, tBy, T_Man, T_Core, Tp_M, Tp_D, T_CMB, r_ICB
!        Write ( 21,* ) it, tBy, T_Man, T_Core, Tp_M, Tp_D, T_CMB, r_ICB

      T_Man_C  = T_Man  - T_0C
      Tp_M_C   = Tp_M   - T_0C
      Tp_D_C   = Tp_D   - T_0C
      T_CMB_C  = T_CMB  - T_0C  
      T_Core_C = T_Core - T_0C
      T_ICB_C  = T_ICB  - T_0C
      r_ICB_K  = r_ICB / 1000.0d0

      Write ( 6,* )  it, tBy, T_Man_C, T_Core_C, Tp_M_C, Tp_D_C,               & 
                     T_CMB_C, T_ICB_C, r_ICB_K
      Write ( 21,* ) it, tBy, T_Man_C, T_Core_C, Tp_M_C, Tp_D_C,               &
                     T_CMB_C, T_ICB_C, r_ICB_K

!   Time marching loop by Runge-Kutta Method  +++++++++++++++++++++++++++++++++++

      do it = 1,Nt
        t0 = t
        t1 = t + dt *0.5d0
        t2 = t + dt

!  Step 1: Calculate dT(t=t0)/dt

        iRKS = 1
        T_Man0  = T_Man
        T_Core0 = T_Core

        Tp_M0   = Tp_M
        T_CMB0  = T_CMB

        call RKF_Man ( F_Man1,  Q_CMB0, T_Man0,  Tp_M0,  T_CMB0, t0, it, iRKS ) 
        call RKF_Core( F_Core1, Q_CMB0, T_Core0, T_CMB0,         t0, it, iRKS )

!  Step 2: Calculate dT_1(t=t1)/dt
      
        iRKS = 2
        T_Man1  = T_Man  + F_Man1 * dt / 2.0d0
        T_Core1 = T_Core + F_Core1 * dt / 2.0d0

        Tp_M1   = Theta_M * T_Man1
        T_CMB1  = Theta_C * T_Core1

        call RKF_Man ( F_Man2,  Q_CMB1, T_Man1,  Tp_M1,  T_CMB1, t1, it, iRKS ) 
        call RKF_Core( F_Core2, Q_CMB1, T_Core1, T_CMB1,         t1, it, iRKS )

!  Step 3: Calculate dT_2(t=t1)/dt

        iRKS = 3
        T_Man2  = T_Man  + F_Man2  * dt / 2.0d0
        T_Core2 = T_Core + F_Core2 * dt / 2.0d0

        Tp_M2   = Theta_M * T_Man2
        T_CMB2  = Theta_C * T_Core2

        call RKF_Man ( F_Man3,  Q_CMB2, T_Man2,  Tp_M2,  T_CMB2, t1, it, iRKS )
        call RKF_Core( F_Core3, Q_CMB2, T_Core2, T_CMB2,         t1, it, iRKS )

!  Step 4: Calculate dT(t=t2)/dt

        iRKS = 4
        T_Man3  = T_Man  + F_Man3  * dt
        T_Core3 = T_Core + F_Core3 * dt

        Tp_M3   = Theta_M * T_Man3
        T_CMB3  = Theta_C * T_Core3

        call RKF_Man ( F_Man4,  Q_CMB3,  T_Man3,  Tp_M3,  T_CMB3,  t2, it, iRKS ) 
        call RKF_Core( F_Core4, Q_CMB3,  T_Core3, T_CMB3,          t2, it, iRKS )

!  Final step

        T_Man_N  = T_Man  +  dt / 6.0d0                                     &
                           * ( F_Man1   + 2.0d0 * F_Man2                    &
                                        + 2.0d0 * F_Man3  + F_Man4  ) 
        T_Core_N = T_Core +  dt / 6.0d0                                     &
                            * ( F_Core1 + 2.0d0 * F_Core2                   &
                                        + 2.0d0 * F_Core3 + F_Core4 )

        t = t2
        tBy = t / SecBy

        T_Man  = T_Man_N
        T_Core = T_Core_N

        Tp_M   = Theta_M * T_Man
        T_CMB  = Theta_C * T_Core

        call cal_Tp_D( Tp_D, Tp_M )

        call cal_ICB_radi( r_ICB, T_CMB )

        call cal_ICB_Tmp ( T_ICB, T_CMB, r_ICB )

!        Write ( 6,* )  it, tBy, T_Man, T_Core, Tp_M, Tp_D, T_CMB, r_ICB
!        Write ( 21,* ) it, tBy, T_Man, T_Core, Tp_M, Tp_D, T_CMB, r_ICB

        T_Man_C  = T_Man  - T_0C
        Tp_M_C   = Tp_M   - T_0C
        Tp_D_C   = Tp_D   - T_0C
        T_CMB_C  = T_CMB  - T_0C  
        T_Core_C = T_Core - T_0C
        T_ICB_C  = T_ICB  - T_0C
        r_ICB_K  = r_ICB / 1000.0d0

        Write ( 6,* )  it, tBy, T_Man_C, T_Core_C, Tp_M_C, Tp_D_C,               & 
                       T_CMB_C, T_ICB_C, r_ICB_K
        Write ( 21,* ) it, tBy, T_Man_C, T_Core_C, Tp_M_C, Tp_D_C,               &
                       T_CMB_C, T_ICB_C, r_ICB_K

      end do

      close ( 20 )
      close ( 21 )
      close ( 22 )
      close ( 23 )

   end program th_main
