!2345678901234567890223456789032345678904234567890523456789062345678907234567890
! ******************************************************************************
! **  set physical parameters                         **
! ******************************************************************************
!   subroutine set_Ra_Nu( HF45_sur, Tp45_D, DT_Man, Ra_ref, Nu_sur )
   subroutine set_Ra_Nu( Ra_ref, Nu_sur )

      use mod_cswitch
      use mod_physp
      use mod_thermp

      implicit none
      real(8):: A,       Tp45_D
      real(8):: Qint45
      real(8):: DT_Man
      real(8):: DT_sur,  HF45_sur, HFC_sur
      real(8):: T_Eta
      real(8):: Nu_sur,  Ra_ref,   be_ref
      real(8):: r_ICB,   T_CMB

!   Calculate reference D" temperature

      A    = alph_M * g_0 / Cp_M

      if ( IADG == 1 ) then
        Tp45_D = Tp45_M * exp( A * ( R_0 - R_CMB ) )
       else
        Tp45_D = Tp45_M * ( 1.0d0 + A * ( R_0 - R_CMB ) )
      end if

!   Surface heat flux and temperature difference

      if ( mod( IPRN, 10 ) <= 2 ) then  ! Global Ra
        DT_Man = Tp45_M - T_sur + T45_CMB - Tp45_D
       else
        DT_Man = Tp45_M - T_sur
      end if

!   Rayleigh number

      Ra_ref = rho_Man * alph_M * DT_Man * g_0 * D_Man**3 / ( Eta45 * kap_M )

!   Nusselt number at the surface

      HF45_sur = Q45_sur / S_Man
      DT_sur   = Tp45_M - T_sur

      if ( IPRN < 10 ) then             ! Spherical shell conduction
        HFC_sur  = k_M * DT_Man * R_CMB / ( D_Man * R_0 )
       else                             ! boundary layer thickness and velocity 
        HFC_sur  = k_M * DT_sur / D_Man
      end if

      Nu_sur   = HF45_sur / HFC_sur

!   Coefficient of Nu for Ra^beta

      A_RaNu_U = Nu_sur / Ra_ref**beta_U
      A_RaNu_L = Nu_sur / Ra_ref**beta_L

      return

   end subroutine set_Ra_Nu



